==> CLDAQ-1.8.2.tar.gz: CLDAQ/examples/vme/st02/St02SinglePixel.cc <==
// =====================================================================
//  $Id: St02SinglePixel.cc,v 1.2 2003/07/30 16:16:35 goiwai Exp $
//  $Name: CLDAQ-1-08-02 $
//
//  $Log: St02SinglePixel.cc,v $
//  Revision 1.2  2003/07/30 16:16:35  goiwai
//  ե˥ߥåȥĤ뤳Ȥˤޤ.
//
// =====================================================================
#include "St02SinglePixel.hh"

St02SinglePixel::St02SinglePixel( Tint h, Tint v, Tdouble signal, Tdouble dark, Tdouble rms )
  : theHorizontalID( h ), theVerticalID( v ),
    theSignal( signal ), theDark( dark ), theRms( rms )
{;}

St02SinglePixel::St02SinglePixel( const St02SinglePixel& right )
  : theHorizontalID( right.theHorizontalID ),
    theVerticalID( right.theVerticalID ),
    theSignal( right.theSignal ),
    theDark( right.theDark ),
    theRms( right.theRms )
{;}

St02SinglePixel::~St02SinglePixel()
{;}

const St02SinglePixel& St02SinglePixel::operator=( const St02SinglePixel& right )
{
  theHorizontalID = right.theHorizontalID;
  theVerticalID = right.theVerticalID;
  theSignal = right.theSignal;
  theDark = right.theDark;
  theRms = right.theRms;
  return( *this );
}

Tbool St02SinglePixel::operator==( const St02SinglePixel& right ) const
{
  Tbool retval = Ttrue;
  retval &= ( theHorizontalID == right.theHorizontalID );
  retval &= ( theVerticalID == right.theVerticalID );
  retval &= ( theSignal == right.theSignal );
  retval &= ( theDark == right.theDark );
  retval &= ( theRms == right.theRms );
  return( retval );
}

Tbool St02SinglePixel::operator!=( const St02SinglePixel& right ) const
{
  Tbool retval = Tfalse;
  retval |= ( theHorizontalID != right.theHorizontalID );
  retval |= ( theVerticalID != right.theVerticalID );
  retval |= ( theSignal != right.theSignal );
  retval |= ( theDark != right.theDark );
  retval |= ( theRms != right.theRms );
  return( retval );
}

Tostream& operator<<( Tostream& tos, const St02SinglePixel& right )
{
  tos << right.theHorizontalID << Tspace;
  tos << right.theVerticalID << Tspace;
  tos << right.theSignal << Tspace;
  tos << right.theDark << Tspace;
  tos << right.theRms << Tflush;
  return( tos );
}

Tistream& operator>>( Tistream& tis, St02SinglePixel& right )
{
  return( tis >> right.theHorizontalID >> right.theVerticalID >> right.theSignal >> right.theDark >> right.theRms );
}

==> CLDAQ-1.10.0.tar.gz: CLDAQ/examples/vme/st02/St02SinglePixel.cc <==
// =====================================================================
//  $Id: St02SinglePixel.cc,v 1.3 2003/10/06 16:28:19 goiwai Exp $
//  $Name: CLDAQ-1-10-00 $
//  $Log: St02SinglePixel.cc,v $
//  Revision 1.3  2003/10/06 16:28:19  goiwai
//  *** empty log message ***
//
//  Revision 1.2  2003/07/30 16:16:35  goiwai
//  ե˥ߥåȥĤ뤳Ȥˤޤ.
//
// =====================================================================
#include "St02SinglePixel.hh"

St02SinglePixel::St02SinglePixel( Tint h, Tint v, Tdouble signal, Tdouble dark, Tdouble rms )
  : theHorizontalID( h ), theVerticalID( v ),
    theSignal( signal ), theDark( dark ), theRms( rms )
{;}

St02SinglePixel::St02SinglePixel( const St02SinglePixel& right )
  : theHorizontalID( right.theHorizontalID ),
    theVerticalID( right.theVerticalID ),
    theSignal( right.theSignal ),
    theDark( right.theDark ),
    theRms( right.theRms )
{;}

St02SinglePixel::~St02SinglePixel()
{;}

const St02SinglePixel& St02SinglePixel::operator=( const St02SinglePixel& right )
{
  theHorizontalID = right.theHorizontalID;
  theVerticalID = right.theVerticalID;
  theSignal = right.theSignal;
  theDark = right.theDark;
  theRms = right.theRms;
  return *this;
}

Tbool St02SinglePixel::operator==( const St02SinglePixel& right ) const
{
  Tbool retval = Ttrue;
  retval &= ( theHorizontalID == right.theHorizontalID );
  retval &= ( theVerticalID == right.theVerticalID );
  retval &= ( theSignal == right.theSignal );
  retval &= ( theDark == right.theDark );
  retval &= ( theRms == right.theRms );
  return retval;
}

Tbool St02SinglePixel::operator!=( const St02SinglePixel& right ) const
{
  Tbool retval = Tfalse;
  retval |= ( theHorizontalID != right.theHorizontalID );
  retval |= ( theVerticalID != right.theVerticalID );
  retval |= ( theSignal != right.theSignal );
  retval |= ( theDark != right.theDark );
  retval |= ( theRms != right.theRms );
  return retval;
}

Tostream& operator<<( Tostream& tos, const St02SinglePixel& right )
{
  tos << right.theHorizontalID << Tspace;
  tos << right.theVerticalID << Tspace;
  tos << right.theSignal << Tspace;
  tos << right.theDark << Tspace;
  tos << right.theRms << Tflush;
  return tos;
}

Tistream& operator>>( Tistream& tis, St02SinglePixel& right )
{
  return tis >> right.theHorizontalID >> right.theVerticalID >> right.theSignal >> right.theDark >> right.theRms;
}
